@@ -4,4 +4,4 @@ from pregex import groups as gr
 from pregex import operators as op
 from pregex import quantifiers as qu
 from pregex import tokens as tk
-from pregex.pre import Pregex
\ No newline at end of file
+from pregex.pre import Pregex, Empty
\ No newline at end of file
